@@ -48,6 +48,7 @@
 #include <io.h>
 #include <fcntl.h>
 #endif
+#include <math.h>
 
 #ifdef HAVE_SYS_SOUNDCARD_H
 #include <sys/soundcard.h>
@@ -196,8 +197,8 @@ void usage()
    printf ("  (nothing)            Will be played to soundcard\n");
    printf ("\n");  
    printf ("Options:\n");
-   printf (" --enh                 Enable perceptual enhancement\n");
-   printf (" --no-enh              Disable perceptual enhancement (default FOR NOW)\n");
+   printf (" --enh                 Enable perceptual enhancement (default)\n");
+   printf (" --no-enh              Disable perceptual enhancement\n");
    printf (" --force-nb            Force decoding in narrowband\n");
    printf (" --force-wb            Force decoding in wideband\n");
    printf (" --force-uwb           Force decoding in ultra-wideband\n");
@@ -208,8 +209,8 @@ void usage()
    printf (" -V                    Verbose mode (show bit-rate)\n"); 
    printf (" -h, --help            This help\n");
    printf (" -v, --version         Version information\n");
-   printf (" --pf                  Deprecated, use --pf instead\n");
-   printf (" --no-pf               Deprecated, use --no-pf instead\n");
+   printf (" --pf                  Deprecated, use --enh instead\n");
+   printf (" --no-pf               Deprecated, use --no-enh instead\n");
    printf ("\n");
    printf ("More information is available from the Speex site: http://www.speex.org\n");
    printf ("\n");
@@ -353,7 +354,7 @@ int main(int argc, char **argv)
    int channels=-1;
    int rate=0;
 
-   enh_enabled = 0;
+   enh_enabled = 1;
 
    /*Process options*/
    while(1)
@@ -551,7 +552,7 @@ int main(int argc, char **argv)
                   }
                   /*Convert to short and save to output file*/
                   for (i=0;i<frame_size*channels;i++)
-                     out[i]=(short)le_short((short)output[i]);
+                     out[i]=(short)le_short((short)floor(.5+output[i]));
 #if defined WIN32 || defined _WIN32
                   if (strlen(outFile)==0)
                       WIN_Play_Samples (out, sizeof(short) * frame_size*channels);
@@ -606,5 +607,5 @@ int main(int argc, char **argv)
    if (fout != NULL)
       fclose(fout);   
 
-   return 1;
+   return 0;
 }
