@@ -144,6 +144,9 @@ void usage()
    printf (" --quality n        Encoding quality (0-10), default 3\n"); 
    printf (" --bitrate n        Encoding bit-rate (use bit-rate n or lower)\n"); 
    printf (" --vbr              Enable variable bit-rate (VBR)\n"); 
+   printf (" --abr rate         Enable average bit-rate (ABR) at rate bps\n"); 
+   printf (" --vad              Enable voice activity detection (VAD)\n"); 
+   printf (" --dtx              Enable file-based discontinuous transmission (DTX)\n"); 
    printf (" --comp n           Set encoding complexity (0-10), default 3\n"); 
    printf (" --nframes n        Number of frames per Ogg packet (1-10), default 1\n"); 
    printf (" --comment          Add the given string as an extra comment. This may be\n");
@@ -177,6 +180,9 @@ int main(int argc, char **argv)
    float input[MAX_FRAME_SIZE];
    int frame_size;
    int vbr_enabled=0;
+   int abr_enabled=0;
+   int vad_enabled=0;
+   int dtx_enabled=0;
    int nbBytes;
    SpeexMode *mode=NULL;
    void *st;
@@ -188,6 +194,9 @@ int main(int argc, char **argv)
       {"ultra-wideband", no_argument, NULL, 0},
       {"narrowband", no_argument, NULL, 0},
       {"vbr", no_argument, NULL, 0},
+      {"abr", required_argument, NULL, 0},
+      {"vad", no_argument, NULL, 0},
+      {"dtx", no_argument, NULL, 0},
       {"quality", required_argument, NULL, 0},
       {"bitrate", required_argument, NULL, 0},
       {"nframes", required_argument, NULL, 0},
@@ -227,7 +236,7 @@ int main(int argc, char **argv)
    int close_in=0, close_out=0;
    int eos=0;
    int bitrate=0;
-
+   int cumul_bits=0, enc_frames=0;
    comment_init(&comments, &comments_length, vendor_string);
 
    /*Process command-line options*/
@@ -253,6 +262,20 @@ int main(int argc, char **argv)
          } else if (strcmp(long_options[option_index].name,"vbr")==0)
          {
             vbr_enabled=1;
+         } else if (strcmp(long_options[option_index].name,"abr")==0)
+         {
+            abr_enabled=atoi(optarg);
+            if (!abr_enabled)
+            {
+               fprintf (stderr, "Invalid ABR value: %d\n", abr_enabled);
+               exit(1);
+            }
+         } else if (strcmp(long_options[option_index].name,"vad")==0)
+         {
+            vad_enabled=1;
+         } else if (strcmp(long_options[option_index].name,"dtx")==0)
+         {
+            dtx_enabled=1;
          } else if (strcmp(long_options[option_index].name,"quality")==0)
          {
             quality = atoi (optarg);
@@ -528,12 +551,6 @@ int main(int argc, char **argv)
    speex_encoder_ctl(st, SPEEX_SET_COMPLEXITY, &complexity);
    speex_encoder_ctl(st, SPEEX_SET_SAMPLING_RATE, &rate);
 
-   if (vbr_enabled)
-   {
-      int tmp;
-      tmp=1;
-      speex_encoder_ctl(st, SPEEX_SET_VBR, &tmp);
-   }
    if (quality >= 0)
    {
       if (vbr_enabled)
@@ -547,6 +564,23 @@ int main(int argc, char **argv)
          fprintf (stderr, "--bitrate option is overriding --quality\n");
       speex_encoder_ctl(st, SPEEX_SET_BITRATE, &bitrate);
    }
+   if (vbr_enabled)
+   {
+      int tmp;
+      tmp=1;
+      speex_encoder_ctl(st, SPEEX_SET_VBR, &tmp);
+   } else if (vad_enabled)
+   {
+      int tmp;
+      tmp=1;
+      speex_encoder_ctl(st, SPEEX_SET_VAD, &tmp);
+      if (dtx_enabled)
+         speex_encoder_ctl(st, SPEEX_SET_DTX, &tmp);
+   }
+   if (abr_enabled)
+   {
+      speex_encoder_ctl(st, SPEEX_SET_ABR, &abr_enabled);
+   }
 
    speex_bits_init(&bits);
 
@@ -567,7 +601,13 @@ int main(int argc, char **argv)
          char ch=13;
          speex_encoder_ctl(st, SPEEX_GET_BITRATE, &tmp);
          fputc (ch, stderr);
-         fprintf (stderr, "Bitrate is use: %d bps     ", tmp);
+         cumul_bits += tmp;
+         enc_frames++;
+         if (vad_enabled || vbr_enabled || abr_enabled)
+            fprintf (stderr, "Bitrate is use: %d bps  (average %d bps)   ", tmp, cumul_bits/enc_frames);
+         else
+            fprintf (stderr, "Bitrate is use: %d bps     ", tmp);
+         
       }
 
       if (read_samples(fin,frame_size,fmt,chan,lsb,input))
@@ -642,7 +682,7 @@ int main(int argc, char **argv)
       fclose(fin);
    if (close_out)
       fclose(fout);
-   return 1;
+   return 0;
 }
 
 /*                 
